/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <dlog.h>

#include <memory>
#include <string>

#include "component_based/common/exception.h"
#include "component_based/base/action_internal.h"

namespace component_based {
namespace internal {

Action::Action(std::string name, Action::IEventListener* ev)
  : ev_(ev) {
  if (app_control_add_action_handler(name.c_str(), OnActionCB, ev_, &handle_)
      != APP_CONTROL_ERROR_NONE) {
    THROW(Exception::ErrorCodes::InvalidParameter);
  }
}

Action::~Action() {
  if (handle_ != nullptr)
    app_control_remove_action_handler(handle_);
}

void Action::OnActionCB(const char* action, app_control_h app_control,
                        void* user_data) {
  IEventListener* ev = static_cast<IEventListener*>(user_data);
  try {
    ev->OnAction(std::string(action), AppControl(app_control));
  } catch(Exception& ex) {
    LOGE("Exception occurred (%s)", ex.what());
  }
}

}  // namespace internal
}  // namespace component_based
