/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_BASED_BASE_ACTION_INTERNAL_H_
#define COMPONENT_BASED_BASE_ACTION_INTERNAL_H_

#include <memory>
#include <string>

#include "component_based/app_control/component_based_app_control.h"

namespace component_based {
namespace internal {

class Action {
 public:
  class IEventListener {
   public:
    virtual void OnAction(std::string action_name, AppControl control) = 0;
  };

  Action(std::string name, IEventListener* ev);
  virtual ~Action();

 private:
  static void OnActionCB(const char* action, app_control_h app_control,
                         void* user_data);

 private:
  IEventListener* ev_;
  app_control_action_h handle_ = nullptr;
};

}  // namespace internal
}  // namespace component_based

#endif  // COMPONENT_BASED_BASE_ACTION_INTERNAL_H_
