/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TIZEN_COMPONENT_BASED_BASE_APPLICATION_H__
#define __TIZEN_COMPONENT_BASED_BASE_APPLICATION_H__

#include <app_common.h>

#include <component_common.h>
#include <base_frame_component.h>
#include <base_service_component.h>
#include <base_component.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void (*component_based_app_base_init_cb)(int argc, char **argv, void *user_data);
typedef void (*component_based_app_base_fini_cb)(void *user_data);
typedef void (*component_based_app_base_run_cb)(void *user_data);
typedef void (*component_based_app_base_exit_cb)(void *user_data);
typedef component_class_h (*component_based_app_base_create_cb)(void *user_data);
typedef void (*component_based_app_base_terminate_cb)(void *user_data);

typedef enum {
	COMPONENT_TYPE_FRAME,
	COMPONENT_TYPE_SERVICE,
} component_type_e;

typedef struct {
	component_based_app_base_init_cb init;
	component_based_app_base_fini_cb fini;
	component_based_app_base_run_cb run;
	component_based_app_base_exit_cb exit;
	component_based_app_base_create_cb create;
	component_based_app_base_terminate_cb terminate;
} component_based_app_base_lifecycle_callback_s;

int component_based_app_base_main(int argc, char **argv,
		component_based_app_base_lifecycle_callback_s *callback,
		void *user_data);

int component_based_app_base_exit(void);

component_class_h component_based_app_base_add_frame_component(
		component_class_h comp_class,
		const char *comp_id,
		base_frame_component_lifecycle_callback_s *callback,
		void *user_data);

component_class_h component_based_app_base_add_service_component(
		component_class_h comp_class,
		const char *comp_id,
		base_service_component_lifecycle_callback_s *callback,
		void *user_data);

component_class_h component_based_app_base_add_base_component(
		component_class_h comp_class,
		component_type_e type,
		const char *comp_id,
		base_component_lifecycle_callback_s *callback,
		void *user_data);

/**
 * @}
 */

#ifdef __cplusplus
}
#endif
#endif /* __TIZEN_COMPONENT_BASED_BASE_APPLICATION_H__ */

