/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_BASED_BASE_APPLICATION_BASE_IMPLEMENTATION_H_
#define COMPONENT_BASED_BASE_APPLICATION_BASE_IMPLEMENTATION_H_

#include <string>

#include "component_based/base/application_base.h"
#include "component_based/base/core_base_internal.h"

namespace component_based {

class ApplicationBase::Impl : internal::CoreBase::IEventListener {
 public:
  virtual ~Impl() = default;
  void OnBaseInit(int argc, char** argv) override;
  void OnBaseFinish() override;
  void OnBaseRun() override;
  void OnBaseExit() override;
  bool OnBaseCreate() override;
  void OnBaseTerminate() override;
  void OnBaseReceive(aul_type type, bundle* b) override;
  void OnBaseControl(bundle* b) override;

  void OnWindowShow(int type, void* event) override;
  void OnWindowHide(int type, void* event) override;
  void OnWindowLower(int type, void* event) override;
  void OnWindowPreVisibility(int type, void* event) override;
  void OnWindowVisibility(int type, void* event) override;
  void OnWindowAuxMessage(int type, void* event) override;

  int Run(int argc, char** argv);
  void Exit(void);

  const std::string& GetApplicationID() {
    return app_id_;
  }

 private:
  friend class ApplicationBase;
  explicit Impl(ApplicationBase* parent);

 private:
  ApplicationBase* parent_;
  std::unique_ptr<internal::CoreBase> core_base_;
  std::string app_id_;
  bool exiting_ = false;
};

}  // namespace component_based

#endif  // COMPONENT_BASED_BASE_APPLICATION_BASE_IMPLEMENTATION_H_
