/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_BASED_BASE_FRAME_COMPONENT_H_
#define COMPONENT_BASED_BASE_FRAME_COMPONENT_H_

#include <string>

#include "component_based/base/component.h"
#include "component_based/base/window_interface.h"

#ifndef EXPORT_API
#define EXPORT_API __attribute__((visibility("default")))
#endif

namespace component_based {

class EXPORT_API FrameComponent : public Component {
 public:
  class Factory : public Component::Factory {
   public:
    std::unique_ptr<Component> Create(std::string comp_id,
                                      std::string inst_id) override {
      return std::unique_ptr<Component>(
          new (std::nothrow) FrameComponent(
            std::move(comp_id), std::move(inst_id)));
    }
  };

  enum class DisplayStatus {
    Unknown,
    On,
    Off,
  };

  FrameComponent(std::string comp_id, std::string inst_id);
  virtual ~FrameComponent();

  DisplayStatus GetDisplayStatus();
  const IWindow* GetWindow();

  bool OnBaseCreate() override;
  void OnBaseDestroy() override;
  void OnBaseStart(AppControl control, bool restarted) override;
  void OnBaseResume() override;
  void OnBasePause() override;
  void OnBaseStop() override;
  void OnBaseRestoreContent(tizen_base::Bundle content) override;
  void OnBaseSaveContent(tizen_base::Bundle& content) override;
  void OnBaseAction(std::string action, AppControl app_control) override;
  void OnBaseDeviceOrientationChanged(
      DeviceOrientation::Orientation orientation) override;
  void OnBaseLanguageChanged(std::string language) override;
  void OnBaseRegionFormatChanged(std::string region) override;
  void OnBaseLowBattery(LowBattery::Status status) override;
  void OnBaseLowMemory(LowMemory::Status status) override;
  void OnBaseSuspendedStateChanged(SuspendedState::State state) override;

  virtual std::unique_ptr<IWindow> OnCreate();
  virtual void OnStart(AppControl app_control, bool restarted);
  virtual void OnResume();
  virtual void OnPause();
  virtual void OnStop();
  virtual void OnDestroy();
};

}  // namespace component_based

#endif  // COMPONENT_BASED_BASE_FRAME_COMPONENT_H_
