/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <memory>

#include "component_based/base/service_component.h"

namespace component_based {

ServiceComponent::ServiceComponent(std::string comp_id, std::string inst_id)
  : Component::Component(Component::Type::Service, std::move(comp_id),
                         std::move(inst_id)) {
}

ServiceComponent::~ServiceComponent() = default;

bool ServiceComponent::OnBaseCreate() {
  bool r = OnCreate();
  if (!r) {
    LOGE("OnCreate() returns false");
    return false;
  }
  return true;
}

void ServiceComponent::OnBaseDestroy() {
  OnDestroy();
}

void ServiceComponent::OnBaseStart(AppControl control, bool restarted) {
  tizen_base::Bundle content = GetContent();
  OnBaseRestoreContent(content);
  OnStartCommand(control, restarted);
  OnBaseSaveContent(content);
  SetContent(std::move(content));
}

void ServiceComponent::OnBaseResume() {
}

void ServiceComponent::OnBasePause() {
}

void ServiceComponent::OnBaseStop() {
}

void ServiceComponent::OnBaseRestoreContent(tizen_base::Bundle content) {
}

void ServiceComponent::OnBaseSaveContent(tizen_base::Bundle& content) {
}

void ServiceComponent::OnBaseAction(std::string action, AppControl app_control) {
}

void ServiceComponent::OnBaseDeviceOrientationChanged(
    DeviceOrientation::Orientation orientation) {
}

void ServiceComponent::OnBaseLanguageChanged(std::string language) {
}

void ServiceComponent::OnBaseRegionFormatChanged(std::string region) {
}

void ServiceComponent::OnBaseLowBattery(LowBattery::Status status) {
}

void ServiceComponent::OnBaseLowMemory(LowMemory::Status status) {
}

void ServiceComponent::OnBaseSuspendedStateChanged(SuspendedState::State state) {
}

bool ServiceComponent::OnCreate() {
  return false;
}

void ServiceComponent::OnStartCommand(AppControl app_control, bool restarted) {
}

void ServiceComponent::OnDestroy() {
}

}  // namespace component_based
