/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef COMPONENT_BASED_COMMON_EXCEPTION_H_
#define COMPONENT_BASED_COMMON_EXCEPTION_H_

#include <exception>
#include <string>

#define THROW(error_code) throw Exception(error_code, __FILE__, __LINE__)

namespace component_based {

class Exception : public std::exception {
 public:
  enum class ErrorCodes {
    InvalidParameter,
    OutOfMemory,
    IOError,
  };
  explicit Exception(ErrorCodes error_code, std::string file = __FILE__,
      int line = __LINE__ ) {
    error_code_ = error_code;
    message_ = file.substr(file.find_last_of("/") + 1) + ":"
        + std::to_string(line) + GetErrorString(error_code);
  }
  virtual ~Exception() {}
  virtual const char *what(void) const noexcept {
    return message_.c_str();
  }
  ErrorCodes GetErrorCode() {
    return error_code_;
  }

 private:
  ErrorCodes error_code_;
  std::string message_;
  std::string GetErrorString(ErrorCodes error_code) {
    switch (error_code) {
    case ErrorCodes::InvalidParameter:
      return ": INVALID_PARAMETER";
    case ErrorCodes::OutOfMemory:
      return ": OUT_OF_MEMORY";
    case ErrorCodes::IOError:
      return ": ERROR_IO_ERROR";
    default:
      return "";
    }
  }
};

}  // namespace component_based

#endif  // COMPONENT_BASED_COMMON_EXCEPTION_H_
