/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Ecore_Wl2.h>

#include <memory>

#include "component_based/efl_base/elm_window.h"

namespace component_based {

ElmWindow::ElmWindow(std::string id) {
  win_ = elm_win_util_standard_add(id.c_str(), id.c_str());
}

ElmWindow::ElmWindow(Evas_Object* win) : win_(win) {
}

ElmWindow::~ElmWindow() {
  if (win_ != nullptr)
    evas_object_del(win_);
}

int ElmWindow::GetResID() const {
  Evas* evas = evas_object_evas_get(win_);
  Ecore_Evas* ecore_evas = ecore_evas_ecore_evas_get(evas);
  Ecore_Wl2_Window* wl_win = ecore_evas_wayland2_window_get(ecore_evas);
  return ecore_wl2_window_id_get(wl_win);
}

void* ElmWindow::GetRaw() {
  return win_;
}

}  // namespace component_based
