/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __TIZEN_APPFW_COMPONENT_BASED_APPLICATION_DOC_H__
#define __TIZEN_APPFW_COMPONENT_BASED_APPLICATION_DOC_H__

/**
 * @defgroup COMPONENT_BASED_APPLICATION_MODULE Component Based Application
 * @ingroup CAPI_APPLICATION_FRAMEWORK
 * @brief Component based application API.
 *
 * @section COMPONENT_BASED_APPLICATION_MODULE_HEADER Required Header
 * \#include <component_based_app.h>
 *
 * @section COMPONENT_BASED_APPLICATION_MODULE_OVERVIEW Overview
 * The @ref COMPONENT_BASED_APPLICATION_MODULE API provides functions for starting and exiting Tizen component based application. Tizen component based application can consist of frame_component and service_component.
 * This API supports making multiple frame_components and service_components per an application.
 *
 * @subsection COMPONENT_BASED_APPLICATION_MODULE_STATE_CHANGE_EVENT Registering Callbacks for Application State Change Events
 * As for Tizen component based application states, it is very simple and somewhat similar to Tizen widget application states.
 * <p>
 * <table>
 * <tr>
 *   <th> Callback </th>
 *   <th> Description </th>
 * </tr>
 * <tr>
 *   <td> component_based_app_create_cb() </td>
 *   <td> The callback function is called before the main loop of the application starts.
 *   In this callback, you can initialize resources which can be shared among component instances.
 *   This function should return the handle for component class so that it will be used for making instances of component.
 *   </td>
 * </tr>
 * <tr>
 *   <td> component_based_app_terminate_cb() </td>
 *   <td> This callback function is called once after the main loop of the application exits.
 *   You should release the resources of the application in this function.
 *   </td>
 * </tr>
 * </table>
 * </p>
 */

/**
 * @defgroup COMPONENT_BASED_COMPONENT_COMMON_MODULE Component Based Common
 * @ingroup COMPONENT_BASED_APPLICATION_MODULE
 * @brief The @ref COMPONENT_BASED_COMPONENT_COMMON_MODULE Registering action for Application Control and Launching request for Application Control.
 *
 * @section COMPONENT_BASED_COMPONENT_COMMON_MODULE_HEADER Required Header
 *   \#include <component_common.h>
 *
 * @section COMPONENT_BASED_COMPONENT_COMMON_MODULE_OVERVIEW Overview
 * The @ref COMPONENT_BASED_COMPONENT_COMMON_MODULE API provides functions for registering and deregistering action for app-control and provides functions for launching request with the app-control synchronous or asynchronous.
 */

/**
 * @defgroup COMPONENT_BASED_FRAME_COMPONENT_MODULE Frame Component
 * @ingroup COMPONENT_BASED_APPLICATION_MODULE
 * @brief The @ref COMPONENT_BASED_FRAME_COMPONENT_MODULE API provides functions for handling Frame Component state changes or system events, and get information about the Frame Component
 *
 * @section COMPONENT_BASED_FRAME_COMPONENT_MODULE_HEADER Required Header
 *   \#include <frame_component.h>
 *
 * @section COMPONENT_BASED_FRAME_COMPONENT_MODULE_OVERVIEW Overview
 * The @ref COMPONENT_BASED_FRAME_COMPONENT_MODULE API provides functions for handling Frame Component of Component Based Application state changes or system events.
 *
 * @subsection COMPONENT_BASED_FRAME_COMPONENT_MODULE_STATE_CHANGE_EVENT Registering Callbacks for Frame Component State Change Events
 * The frame component state change events include the following:
 * <p>
 * <table>
 * <tr>
 *  <th> State </th>
 *  <th> Description </th>
 * </tr>
 * <tr>
 *  <td> frame_component_create_cb() </td>
 *  <td> The callback function called after the frame component instance is created.
 * </td>
 * </tr>
 * <tr>
 *  <td> frame_component_start_cb() </td>
 *  <td> The callback function called when the frame component instance is started.
 * </td>
 * </tr>
 * <tr>
 *  <td> frame_component_resume_cb() </td>
 *  <td> The callback function called when the frame component becomes visible.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_pause_cb() </td>
 *  <td> The callback function called when the frame component becomes invisible.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_stop_cb() </td>
 *  <td> The callback function called before the frame component instance is stopped.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_destroy_cb() </td>
 *  <td> The callback function called before the frame component instance is destroyed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_restore_content_cb() </td>
 *  <td> The callback function called when the content information of the frame component instance is restored.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_save_content_cb() </td>
 *  <td> The callback function called before the content information of the frame component instance is saved.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_action_cb() </td>
 *  <td> The callback function called when another application sends a launch request to the component.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_device_orientation_changed_cb() </td>
 *  <td> The callback function called when the device orientation is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_language_changed_cb() </td>
 *  <td> The callback function called when the system language is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_region_format_changed_cb() </td>
 *  <td> The callback function called when the system region format is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_low_battery_cb() </td>
 *  <td> The callback function called when the battery status is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_low_memory_cb() </td>
 *  <td> The callback function called when the memory status is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> frame_component_suspended_state_changed_cb() </td>
 *  <td> The callback function called when the suspended state of the frame component is changed.
 *  </td>
 * </tr>
 * </table>
 * </p>
 * Please refer to the following state diagram to see the possible transitions and callbacks that are called while transition.
 *
 * @image html frame_component_lifecycle.png "Frame Component States"
 */

/**
 * @defgroup COMPONENT_BASED_SERVICE_COMPONENT_MODULE Service Component
 * @ingroup COMPONENT_BASED_APPLICATION_MODULE
 * @brief The @ref COMPONENT_BASED_SERVICE_COMPONENT_MODULE API provides functions for handling Service Component state changes or system events.
 *
 * @section COMPONENT_BASED_SERVICE_COMPONENT_MODULE_HEADER Required Header
 *   \#include <service_component.h>
 *
 * @section COMPONENT_BASED_SERVICE_COMPONENT_MODULE_OVERVIEW Overview
 * The @ref COMPONENT_BASED_SERVICE_COMPONENT_MODULE API provides functions for handling Service Component of Component Based Application state changes or system events.
 *
 * @subsection COMPONENT_BASED_SERVICE_COMPONENT_MODULE_STATE_CHANGE_EVENT Registering Callbacks for Service Component State Change Events
 * The service component state change events include the following:
 * <p>
 * <table>
 * <tr>
 *  <th> State </th>
 *  <th> Description </th>
 * </tr>
 * <tr>
 *  <td> service_component_create_cb() </td>
 *  <td> The callback function called after the service component instance is created.
 * </td>
 * </tr>
 * <tr>
 *  <td> service_component_start_command_cb() </td>
 *  <td> The callback function called when the service component instance is started.
 * </td>
 * </tr>
 * <tr>
 *  <td> service_component_destroy_cb() </td>
 *  <td> The callback function called before the service component instance is destroyed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_restore_content_cb() </td>
 *  <td> The callback function called when the content information of the service component instance is restored.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_save_content_cb() </td>
 *  <td> The callback function called before the content information of the service component instance is saved.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_action_cb() </td>
 *  <td> The callback function called when another application sends a launch request to the component.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_device_orientation_changed_cb() </td>
 *  <td> The callback function called when the device orientation is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_language_changed_cb() </td>
 *  <td> The callback function called when the system language is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_region_format_changed_cb() </td>
 *  <td> The callback function called when the system region format is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_low_battery_cb() </td>
 *  <td> The callback function called when the battery status is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_low_memory_cb() </td>
 *  <td> The callback function called when the memory status is changed.
 *  </td>
 * </tr>
 * <tr>
 *  <td> service_component_suspended_state_changed_cb() </td>
 *  <td> The callback function called when the suspended state of the service component is changed.
 *  </td>
 * </tr>
 * </table>
 * </p>
 * Please refer to the following state diagram to see the possible transitions and callbacks that are called while transition.
 *
 * @image html service_component_lifecycle.png "Service Component States"
 */

#endif /* __TIZEN_APPFW_COMPONENT_BASED_APPLICATION_DOC_H__ */
