/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdlib.h>
#include <gtest/gtest.h>

#include <iostream>
#include <memory>

#include "unit_tests/mock/mock_app_control.h"
#include "component_based/app_control/component_based_app_control.h"

static const char ENCODED_URI[] = "https:%2F%2Fjohn.doe%40www.example.com%3A123%2Fforum%2Fquestions%2F?tag=networking&order=newest#top";
static const char MIME_TYPE[] = "application/octet-stream";

class AppControlTest : public testing::Test {
 public:
  virtual void SetUp() { }
  virtual void TearDown() {}
};

TEST_F(AppControlTest, AppControl_Builder) {
  std::unique_ptr<component_based::AppControl::Builder> builder(
      new component_based::AppControl::Builder());
  EXPECT_NE(builder, nullptr);

  builder->SetAppID("org.tizen.helloworld");
  builder->SetOperation(APP_CONTROL_OPERATION_DEFAULT);
  builder->SetLaunchMode(component_based::AppControl::LaunchMode::SINGLE);
  builder->SetUri(component_based::Uri(ENCODED_URI));
  builder->SetMime(MIME_TYPE);
  builder->AddExtra("key", "value");
  builder->SetComponentID("ElmFrame");

  component_based::AppControl ctrl = builder->Build();
  EXPECT_EQ(ctrl.GetAppID(), "org.tizen.helloworld");
  EXPECT_EQ(ctrl.GetOperation(), APP_CONTROL_OPERATION_DEFAULT);
  EXPECT_EQ(ctrl.GetLaunchMode(),
      component_based::AppControl::LaunchMode::SINGLE);
  EXPECT_EQ(ctrl.GetUri().Encode(), ENCODED_URI);
  EXPECT_EQ(ctrl.GetMime(), MIME_TYPE);
  EXPECT_EQ(ctrl.GetExtra("key"), "value");
  EXPECT_EQ(ctrl.GetComponentID(), "ElmFrame");
}

TEST_F(AppControlTest, AppControl_Constructor) {
  std::unique_ptr<component_based::AppControl::Builder> builder(
      new component_based::AppControl::Builder());
  EXPECT_NE(builder, nullptr);

  builder->SetAppID("org.tizen.helloworld");
  builder->SetOperation(APP_CONTROL_OPERATION_DEFAULT);
  builder->SetLaunchMode(component_based::AppControl::LaunchMode::SINGLE);
  builder->SetUri(component_based::Uri(ENCODED_URI));
  builder->SetMime(MIME_TYPE);
  builder->AddExtra("key", "value");
  builder->SetComponentID("ElmFrame");

  component_based::AppControl ctrl = builder->Build();

  component_based::AppControl ctrl1(ctrl);
  ctrl1 = ctrl;
  component_based::AppControl ctrl3(std::move(ctrl));
  ctrl3 = std::move(ctrl);
}
