// Copyright (c) 2019 Samsung Electronics Co., Ltd All Rights Reserved
// Use of this source code is governed by a apache 2.0 license that can be
// found in the LICENSE file.

#include <gmock/gmock.h>
#include <gtest/gtest.h>
#include <stdlib.h>

#include "component_based/base/frame_component.h"
#include "component_based/efl_base/application.h"
#include "component_based/efl_base/elm_window.h"

#include "unit_tests/mock/mock_app_common.h"
#include "unit_tests/mock/mock_elementary.h"

namespace {

class ComponentBasedApplicationTest : public ::testing::Test {
 protected:
  void SetUp() override {}
  void TearDown() override {}
};

class SimpleFrameComp : public component_based::FrameComponent {
 public:
  class Factory : public component_based::Component::Factory {
   public:
    std::unique_ptr<component_based::Component> Create(std::string comp_id,
                                            std::string inst_id) override {
      return std::unique_ptr<component_based::Component>(
          new SimpleFrameComp(std::move(comp_id), std::move(inst_id)));
    }
  };

  SimpleFrameComp(std::string comp_id, std::string inst_id)
    : FrameComponent(std::move(comp_id), std::move(inst_id)) {
  }

  std::unique_ptr<component_based::IWindow> OnCreate() override {
    return std::unique_ptr<component_based::IWindow>(new component_based::ElmWindow(GetInstanceID()));
  }

  void OnStart(component_based::AppControl app_control, bool restarted) override {
  }

  void OnResume() override {
  }

  void OnPause() override {
  }

  void OnStop() override {
  }

  void OnDestroy() override {
  }
};

class ServiceComp : public component_based::ServiceComponent {
 public:
  class Factory : public component_based::Component::Factory {
   public:
    std::unique_ptr<component_based::Component> Create(
        std::string comp_id, std::string inst_id) override {
      return std::unique_ptr<component_based::Component>(
          new ServiceComp(std::move(comp_id), std::move(inst_id)));
    }
  };

  ServiceComp(std::string comp_id, std::string inst_id)
    : ServiceComponent(std::move(comp_id), std::move(inst_id)) {
  }

  bool OnCreate() override {
    return true;
  }

  void OnStartCommand(component_based::AppControl app_control,
                      bool restarted) override {
  }

  void OnDestroy() override {
  }
};

int __fake_app_get_id(char** app_id) {
  char id[] = "component_base_test";
  *app_id = strdup(id);
  return 0;
}

int __fake_elm_init(int argc, char** argv) {
  return 0;
}

int __fake_elm_shutdown() {
  return 0;
}

void __fake_elm_run() {
  return;
}

void __fake_elm_exit() {
  return;
}

Evas_Object* __fake_elm_win_util_standard_add(const char* name,
    const char* title)
{
  return nullptr;
}

Evas* __fake_evas_object_evas_get(const Eo* win)
{
  return nullptr;
}

Ecore_Evas* __fake_ecore_evas_ecore_evas_get(const Evas* evas)
{
  return nullptr;
}

Ecore_Wl2_Window* __fake_ecore_evas_wayland2_window_get(const Ecore_Evas* ecore_evas)
{
  return nullptr;
}

int __fake_ecore_wl2_window_id_get(Ecore_Wl2_Window* wl_win)
{
  return 1;
}

TEST_F(ComponentBasedApplicationTest, ApplicationLifeCycle) {
  app_get_id_fake.custom_fake = __fake_app_get_id;
  elm_init_fake.custom_fake = __fake_elm_init;
  elm_shutdown_fake.custom_fake = __fake_elm_shutdown;
  elm_run_fake.custom_fake = __fake_elm_run;
  elm_exit_fake.custom_fake = __fake_elm_exit;

  char* argv[6];

  std::unique_ptr<component_based::Application> app(
      new component_based::Application());

  app->OnInit(2, argv);
  app->OnRun();
  app->OnExit();
  app->OnFini();
}

TEST_F(ComponentBasedApplicationTest, ElmWindow) {
  elm_win_util_standard_add_fake.custom_fake = __fake_elm_win_util_standard_add;
  evas_object_evas_get_fake.custom_fake = __fake_evas_object_evas_get;
  ecore_evas_ecore_evas_get_fake.custom_fake = __fake_ecore_evas_ecore_evas_get;
  ecore_evas_wayland2_window_get_fake.custom_fake =
    __fake_ecore_evas_wayland2_window_get;
  ecore_wl2_window_id_get_fake.custom_fake = __fake_ecore_wl2_window_id_get;

  std::unique_ptr<component_based::ElmWindow> ew(
      new component_based::ElmWindow("id"));

  int resId = ew->GetResID();
  EXPECT_EQ(resId, 1);
  ew->GetRaw();
}

}  // namespace
